@@ -328,7 +328,7 @@ class SSHClient(object):
             if not self.ssh_is_active():
                 if not self.reconnect():
                     raise RuntimeError("ssh transport is not active and failed to reconnect.")
-            if not self.sftp_is_active:
+            if not self.sftp_is_active():
                 self.__sftp = self.__ssh.open_sftp()
             return self._scp_file_to_local(remote_path, local_path)
         except Exception:
